import numpy as np
import matplotlib.pyplot as plt

#filenames
names = ['1_1','1_2','1_3','1_4','2_1','2_2','2_3','2_4',\
'3_1','3_2','3_3','3_4','4_1','4_2','4_3','4_4','5_1','5_2','5_3','5_4']
#temperatures
T = [25.1,25.1,25.1,25.1,28.5,29.7,29.7,28.5,33.9,35.3,35.3,33.9\
,39.3,39.3,40.4,40.4,44,44,45.1,45.1]
#create vector for the half cell potentials
Ehalf = np.zeros(np.shape(T))

n_iter = 0
#loop over all measurements
for num in names:
    filename =  '170622 Jodium 10%  meting ASCII ' + num   
    Data = np.loadtxt(filename, skiprows=1)
    V = Data[:,1]
    I = Data[:,2]*1000
    maxIndex = np.argmax(I[100:])+100  
    minIndex = np.argmin(I[1000:])+1000
    Ehalf[n_iter] = (V[maxIndex]+V[minIndex])/2
    if False:
        plt.plot(V,I, label=num)
        plt.legend() 
        plt.show()
    n_iter += 1
    
#Perform a linear fit on the data    
pars = np.polyfit(T,Ehalf,1)
fT = np.poly1d(pars)
T_fit = np.linspace(20,50,100)
fit_polyI = fT(T_fit)

#Linear coefficient is the Seebeck coefficient
alpha = pars[0]
print('\n\tThe alpha coefficient is:\t%g V/K' %(alpha))

#Fit a triangle in the graph to display the Seebeck coefficient
i1 = 25
i2 = 42
X1 = [T_fit[i1], T_fit[i2]]
Y1 = [fit_polyI[i1], fit_polyI[i1]]
X2 = [T_fit[i2], T_fit[i2]]
Y2 = [fit_polyI[i1], fit_polyI[i2]]
plt.plot(X1,Y1, color = 'black')
plt.plot(X2,Y2, color = 'black')
plt.text(33,0.373,f'+{alpha*1000:.1f} mV/K')


#plot the data and the trendline
plt.plot(T,Ehalf,'o')
plt.plot(T_fit,fit_polyI,'-')
plt.xlabel(u"Temperature (\u00B0C)")
plt.xlim(21.8,48.2)
plt.ylabel(r'E$_{1/2}$ (V vs Ag/AgCl @20C)')
plt.tick_params(axis='both', direction='in')
plt.title(r"Seebeck coefficient: Triiodide 10% ethanol")
plt.show()


   
