import numpy as np
import matplotlib.pyplot as plt

#filenames
names = ['2_2','2_3','2_4','3_2','3_3','3_4'\
         ,'4_2','4_3','4_4','5_2','5_3','5_4','6_2','6_3','6_4']
#temperatures
T = [29.0,29.0,29.0,33.8,34.8,33.8\
,40.4,40.4,40.4,43.9,43.9,43.9,50,50,50]
#create vector for the half cell potentials
Ehalf = np.zeros(np.shape(T))

n_iter = 0
#loop over all measurements
for num in names:
    filename =  '170622 Jodium 20%  meting ASCII ' + num   
    Data = np.loadtxt(filename, skiprows=1)
    V = Data[:,1]
    I = Data[:,2]*1000
    maxIndex = np.argmax(I[100:])+100  
    minIndex = np.argmin(I[1000:])+1000
    Ehalf[n_iter] = (V[maxIndex]+V[minIndex])/2
    if False:
        plt.plot(V,I, label=num)
        plt.legend() 
        plt.show()
    n_iter += 1

#Perform a linear fit on the data    
pars = np.polyfit(T,Ehalf,1)
fT = np.poly1d(pars)
T_fit = np.linspace(25,60,100)
fit_polyI = fT(T_fit)

#Linear coefficient is the Seebeck coefficient
alpha = pars[0]
print('\n\tThe alpha coefficient is:\t%g V/K' %(alpha))

#Fit a triangle in the graph to display the Seebeck coefficient
i1 = 20
i2 = 37
X1 = [T_fit[i1], T_fit[i2]]
Y1 = [fit_polyI[i1], fit_polyI[i1]]
X2 = [T_fit[i2], T_fit[i2]]
Y2 = [fit_polyI[i1], fit_polyI[i2]]
plt.plot(X1,Y1, color = 'black')
plt.plot(X2,Y2, color = 'black')
plt.text(38.5,0.435,f'+{alpha*1000:.1f} mV/K')


#plot the data and the trendline
plt.plot(T,Ehalf,'o')
plt.plot(T_fit,fit_polyI,'-')
plt.xlabel(u"Temperature (\u00B0C)")
plt.xlim(26.8,53.2)
plt.ylabel(r'E$_{1/2}$ (V vs Ag/AgCl @20C)')
plt.tick_params(axis='both', direction='in')
plt.title(r"Seebeck coefficient: Triiodide 20% ethanol")
plt.show()