# -*- coding: utf-8 -*-
"""
Created on Wed Sep 16 22:42:13 2020

@author: jorritbleeker
This script is used to make the figure S-3 of the RFB article
I had trouble finding the original measurement data that Stijn used,

The concentrations used in this measurement are:
Ferrocyanide electrolyte:
    K4Fe(CN)6:  0.1 M
    K3Fe(CN)6:  0.1 M
    KCl:        0.3 M
Iodine electrolyte:
    I2:         0.1 M
    KI:         0.3 M
    KCl:        0.7 M
    
The datapoints were taken from "Resistance Data.xls" tab "15-11",
 which Stijn used to make figure 4.2a in his thesis.
"""
import numpy as np
import matplotlib.pyplot as plt

# Temperature datapoints
T_fresh = np.array([19.955575, 23.605675, 26.6903, 29.741225, 32.834325,
                    36.024225, 39.1353, 42.42645, 46.30555, 48.88815,
                    51.7844, 52.4014, 49.456325, 46.2829925, 43.064775,
                    40.182, 36.932325, 33.7654, 31.30865])

# OCV values at the temperatures above
E_fresh = np.array([-83.08, -96.57, -105.3, -113.7, -121.7, -129.8, -137.8,
                    -146.6, -154.2, -162.2, -170.5, -172.6, -165.4, -157.2,
                    -149.2, -141.1, -132.7, -123.8, -116.9])

# Temperature datapoints after 2 weeks
T_used = np.array([20.997375, 29.2469, 32.93345, 36.28095, 39.119275, 42.14005,
                   45.1883, 48.57155, 51.60935, 54.538075, 57.63745])

# OCV values at the temperatures above
E_used = np.array([-76.99, -98.1, -106.5, -115.4, -122.6, -129.5, -137.1, 
                   -145.2, -152.1, -159.7, -167.3])

# Due to the connection of the electrodes, voltages are measured as negative,
# Fixed to positve as per below, to match to a positive Seebeck coeff.
# Positive Seebeck was proved by CV measurements
E_fresh = E_fresh*-1
E_used = E_used*-1

# Plot the datapoints, Fresh electrolyte = Red, used = Blue
plt.scatter(T_fresh,E_fresh, facecolors='none', edgecolors='r')
plt.scatter(T_used,E_used, facecolors='none', edgecolors='b')
plt.ylabel('OCV (mV)', fontsize = 12)
plt.xlabel(r'Temperature ($\degree$C)', fontsize = 12)
plt.legend(['Fresh electrolyte','After 20 hrs runtime'])
# ---------------------------------------------------
# Linear regression of the fresh electrolyte dataset
# ---------------------------------------------------
coeff_fresh = np.polyfit(T_fresh,E_fresh,1)
E_func_fresh = np.poly1d(coeff_fresh)
T_fit = np.linspace(15,60,100)
E_fit_fresh = E_func_fresh(T_fit)
plt.plot(T_fit,E_fit_fresh, 'r')

# Tweek i1 & i2 to position the triangle with seebeck coefficient
i1 = 20
i2 = 35
X1 = [T_fit[i1], T_fit[i1]]
Y1 = [E_fit_fresh[i1], E_fit_fresh[i2]]
X2 = [T_fit[i1], T_fit[i2]]
Y2 = [E_fit_fresh[i2], E_fit_fresh[i2]]

plt.plot(X1,Y1, color = 'black', linewidth = 1)
plt.plot(X2,Y2, color = 'black', linewidth = 1)
plt.text(17,120, f'+{coeff_fresh[0]:.2f} mV/K')

# ---------------------------------------------------
# Linear regression of the used electrolyte dataset
# ---------------------------------------------------

coeff_used = np.polyfit(T_used,E_used,1)
E_func_used = np.poly1d(coeff_used)
E_fit_used = E_func_used(T_fit)
plt.plot(T_fit,E_fit_used, 'blue')

# Tweek i3 & i4 to position the triangle with seebeck coefficient
i3 = 50
i4 = 65
X3 = [T_fit[i3], T_fit[i4]]
Y3 = [E_fit_used[i3], E_fit_used[i3]]
X4 = [T_fit[i4], T_fit[i4]]
Y4 = [E_fit_used[i3], E_fit_used[i4]]

plt.plot(X3,Y3, color = 'black', linewidth = 1)
plt.plot(X4,Y4, color = 'black', linewidth = 1)
plt.text(45,115, f'+{coeff_used[0]:.2f} mV/K')
plt.xlim(15,60)
plt.tick_params(axis='both',direction='in', top = 'True',right = 'True')
plt.show()
